# Copyright (c) 2007 SUSE LINUX Products GmbH, Nuernberg, Germany.
# Copyright (c) 2007 Hans de Goede <j.w.r.degoede@hhs>, the Fedora project.
#
# This file and all modifications and additions to the pristine
# package are under the same license as the package itself.

Summary:        A heterogeneous set of I2C tools for Linux
Name:           i2c-tools
Version:        4.3
Release:        7%{?dist}
License:        GPLv2+
URL:            https://i2c.wiki.kernel.org/index.php/I2C_Tools
Source0:        https://www.kernel.org/pub/software/utils/i2c-tools/%{name}-%{version}.tar.xz

BuildRequires:  make gcc
BuildRequires:  perl-generators python3-devel
Requires:       systemd-udev kmod
Requires:       libi2c = %{version}-%{release}

%description
This package provides a heterogeneous set of I2C tools for Linux: a bus probing tool, a chip 
dumper, register-level access helpers, EEPROM decoding scripts, and so on.


%package -n python3-i2c-tools
Summary:        Python 3 bindings for Linux SMBus access through i2c-dev
License:        GPLv2
Requires:       libi2c = %{version}-%{release}
Provides:       python3-i2c-tools = %{version}-%{release}

%description -n python3-i2c-tools
This package provides python 3 bindings for Linux SMBus access through i2c-dev.

%package perl
Summary:        i2c tools written in Perl
License:        GPLv2+
Requires:       libi2c = %{version}-%{release}

%description perl
This package provides a collection of tools written in perl for use with i2c devices.

%package -n libi2c
Summary:        I2C/SMBus bus access library
License:        LGPLv2+

%description -n libi2c
This package offers a way for applications to interact with the devices connected to the I2C or 
SMBus buses of the system.

%package -n libi2c-devel
Summary:        Development files for the I2C library
License:        LGPLv2+
Requires:       libi2c = %{version}-%{release}

%description -n libi2c-devel
This package provides development files for the I2C library.

%prep
%autosetup -p1

%build
%make_build BUILD_STATIC_LIB=0 EXTRA=eeprog
pushd py-smbus
CFLAGS="$RPM_OPT_FLAGS -I../include" LDFLAGS="$RPM_LD_FLAGS" \
  %{__python3} setup.py build -b build-py3
popd


%install
%make_install PREFIX=%{_prefix} BUILD_STATIC_LIB=0 EXTRA=eeprog libdir=%{_libdir}
pushd py-smbus
%{__python3} setup.py build -b build-py3 install --skip-build --root=%{buildroot}
popd

rm -f %{buildroot}%{_bindir}/decode-edid.pl
rm -f %{buildroot}%{_bindir}/{ddcmon,decode-edid}

# kmod loads on demand
mkdir -p %{buildroot}%{_prefix}/lib/modprobe.d 
echo "alias char-major-89-* i2c-dev" > \
  %{buildroot}%{_prefix}/lib/modprobe.d/i2c-dev.conf

mkdir -p %{buildroot}%{_sysconfdir}/udev/makedev.d
for (( i = 0 ; i < 8 ; i++ )) do
  echo "i2c-$i" >> %{buildroot}%{_sysconfdir}/udev/makedev.d/99-i2c-dev.nodes
done

# load i2c-dev automatically after reboot
mkdir -p %{buildroot}%{_prefix}/lib/modules-load.d
echo 'i2c-dev' > %{buildroot}%{_prefix}/lib/modules-load.d/%{name}.conf


%post
if [ "$1" = 1 ] ; then
  /usr/sbin/modprobe i2c-dev
fi
exit 0


%files
%license COPYING
%doc CHANGES README
%config(noreplace) %{_prefix}/lib/modprobe.d/i2c-dev.conf
%config(noreplace) %{_sysconfdir}/udev/makedev.d/99-i2c-dev.nodes
%{_sbindir}/i2c*
%{_sbindir}/eeprog
%{_prefix}/lib/modules-load.d/%{name}.conf
%exclude %{_sbindir}/i2c-stub*
%exclude %{_mandir}/man8/i2c-stub-from-dump.8.*
%{_mandir}/man8/i2c*.8.*
%{_mandir}/man8/eeprog.8.*

%files -n python3-i2c-tools
%doc py-smbus/README
%{python3_sitearch}/*

%files perl
%doc eeprom/README
%{_bindir}/decode-*
%{_sbindir}/i2c-stub*
%{_mandir}/man1/decode-*.1.*
%{_mandir}/man8/i2c-stub-from-dump.8.*

%files -n libi2c
%license COPYING.LGPL
%{_libdir}/libi2c.so.0*

%files -n libi2c-devel
%dir %{_includedir}/i2c
%{_includedir}/i2c/smbus.h
%{_libdir}/libi2c.so
%{_mandir}/man3/libi2c.3.*

%changelog
* Thu Sep 26 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 4.3-7
- Rebuilt for clarifying the packages requirement in BaseOS and AppStream

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 4.3-6
- Rebuilt for loongarch release

* Tue Sep 19 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 4.3-5
- Rebuilt for python 3.11

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 4.3-4
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 4.3-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 4.3-2
- Rebuilt for OpenCloudOS Stream 23

* Wed Mar 22 2023 Wang Guodong <gordonwwang@tencent.com> - 4.3-1
- initial build
